Groups | Search | Server Info | Keyboard shortcuts | Login | Register [http] [https] [nntp] [nntps]
Groups > linux.debian.user > #260945
| From | Stefan Monnier <monnier@iro.umontreal.ca> |
|---|---|
| Newsgroups | linux.debian.user |
| Subject | Re: Disk writes much slower in Bookworm i386 [Was: svnadmin dump ...] |
| Date | 2023-08-15 04:10 +0200 |
| Message-ID | <H2RFn-1Wch-1@gated-at.bofh.it> (permalink) |
| References | <H2O4N-1U4g-7@gated-at.bofh.it> |
| Organization | linux.* mail to news gateway |
> I have done additional research, and it now appears that programs that do
> extensive disk writes run much slower (3-6x) in Bookworm than they did in
> Bullseye. The two cases I have observed are 'svnadmin dump', and extracting
> an SQL backup of a Bacula database from Postgresql (backup file about 3 GB).
> Operations that perform extensive reads (a Bacula backup operation to
> magnetic tape, 600 GB) seem to run at the same speed as before.
>
> At the moment, this is a 32-bit PAE system. I don't know of an obvious
> reason why that would matter. At the time of the upgrade, the system memory
> was enlarged from 16 to 32GB, in anticipation of converting the system from
> i386 to amd64.
FWIW, I've had very serious write performance issues on my Thinkpad T61
(8GB RAM + SSD) when using a 32bit PAE kernel (occasionally below 1MB/s,
tho not reliably reproducible, e.g. not right after boot).
Those problems disappeared when I switched to an amd64 kernel (while
keeping the userland 32bit).
https://serverfault.com/questions/996495/writes-throttled-to-500kb-s
Your symptoms seem quite different, but with 16GB of RAN, I'd strongly
suggest you try an amd64 kernel, just in case.
Stefan
Back to linux.debian.user | Previous | Next — Previous in thread | Next in thread | Find similar | Unroll thread
Disk writes much slower in Bookworm i386 [Was: svnadmin dump ...] <kjohnson@eclypse.org> - 2023-08-15 00:20 +0200 Re: Disk writes much slower in Bookworm i386 [Was: svnadmin dump ...] Stefan Monnier <monnier@iro.umontreal.ca> - 2023-08-15 04:10 +0200 Re: Disk writes much slower in Bookworm i386 [Was: svnadmin dump ...] Max Nikulin <manikulin@gmail.com> - 2023-08-15 04:40 +0200
csiph-web